# opsgenie_sdk

OpsgenieSdk - the Ruby gem for the Opsgenie REST API

Opsgenie OpenAPI Specification

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build opsgenie_sdk.gemspec
```

Then either install the gem locally:

```shell
gem install ./opsgenie_sdk-1.0.0.gem
```

(for development, run `gem install --dev ./opsgenie_sdk-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'opsgenie_sdk', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/kwent/opsgenie_sdk, then add the following in the Gemfile:

    gem 'opsgenie_sdk', :git => 'https://github.com/kwent/opsgenie_sdk.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'opsgenie_sdk'

# Setup authorization
OpsgenieSdk.configure do |config|
  # Configure API key authorization: GenieKey
  config.api_key['Authorization'] = 'YOUR API KEY'
  config.api_key_prefix['Authorization'] = 'GenieKey'
end

api_instance = OpsgenieSdk::AccountApi.new

begin
  #Get Account Info
  result = api_instance.get_info
  p result
rescue OpsgenieSdk::ApiError => e
  puts "Exception when calling AccountApi->get_info: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to _https://api.opsgenie.com_

| Class                                  | Method                                                                                               | HTTP request                                                                   | Description                             |
| -------------------------------------- | ---------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------ | --------------------------------------- |
| _OpsgenieSdk::AccountApi_              | [**get_info**](docs/AccountApi.md#get_info)                                                          | **GET** /v2/account                                                            | Get Account Info                        |
| _OpsgenieSdk::AlertApi_                | [**acknowledge_alert**](docs/AlertApi.md#acknowledge_alert)                                          | **POST** /v2/alerts/{identifier}/acknowledge                                   | Acknowledge Alert                       |
| _OpsgenieSdk::AlertApi_                | [**add_attachment**](docs/AlertApi.md#add_attachment)                                                | **POST** /v2/alerts/{identifier}/attachments                                   | Add Alert Attachment                    |
| _OpsgenieSdk::AlertApi_                | [**add_details**](docs/AlertApi.md#add_details)                                                      | **POST** /v2/alerts/{identifier}/details                                       | Add Details                             |
| _OpsgenieSdk::AlertApi_                | [**add_note**](docs/AlertApi.md#add_note)                                                            | **POST** /v2/alerts/{identifier}/notes                                         | Add Note                                |
| _OpsgenieSdk::AlertApi_                | [**add_responder**](docs/AlertApi.md#add_responder)                                                  | **POST** /v2/alerts/{identifier}/responders                                    | Add Responder                           |
| _OpsgenieSdk::AlertApi_                | [**add_tags**](docs/AlertApi.md#add_tags)                                                            | **POST** /v2/alerts/{identifier}/tags                                          | Add Tags                                |
| _OpsgenieSdk::AlertApi_                | [**add_team**](docs/AlertApi.md#add_team)                                                            | **POST** /v2/alerts/{identifier}/teams                                         | Add Team                                |
| _OpsgenieSdk::AlertApi_                | [**assign_alert**](docs/AlertApi.md#assign_alert)                                                    | **POST** /v2/alerts/{identifier}/assign                                        | Assign Alert                            |
| _OpsgenieSdk::AlertApi_                | [**close_alert**](docs/AlertApi.md#close_alert)                                                      | **POST** /v2/alerts/{identifier}/close                                         | Close Alert                             |
| _OpsgenieSdk::AlertApi_                | [**count_alerts**](docs/AlertApi.md#count_alerts)                                                    | **GET** /v2/alerts/count                                                       | Count Alerts                            |
| _OpsgenieSdk::AlertApi_                | [**create_alert**](docs/AlertApi.md#create_alert)                                                    | **POST** /v2/alerts                                                            | Create Alert                            |
| _OpsgenieSdk::AlertApi_                | [**create_saved_searches**](docs/AlertApi.md#create_saved_searches)                                  | **POST** /v2/alerts/saved-searches                                             | Create Saved Search                     |
| _OpsgenieSdk::AlertApi_                | [**delete_alert**](docs/AlertApi.md#delete_alert)                                                    | **DELETE** /v2/alerts/{identifier}                                             | Delete Alert                            |
| _OpsgenieSdk::AlertApi_                | [**delete_saved_search**](docs/AlertApi.md#delete_saved_search)                                      | **DELETE** /v2/alerts/saved-searches/{identifier}                              | Delete Saved Search                     |
| _OpsgenieSdk::AlertApi_                | [**escalate_alert**](docs/AlertApi.md#escalate_alert)                                                | **POST** /v2/alerts/{identifier}/escalate                                      | Escalate Alert                          |
| _OpsgenieSdk::AlertApi_                | [**execute_custom_alert_action**](docs/AlertApi.md#execute_custom_alert_action)                      | **POST** /v2/alerts/{identifier}/actions/{actionName}                          | Custom Alert Action                     |
| _OpsgenieSdk::AlertApi_                | [**get_alert**](docs/AlertApi.md#get_alert)                                                          | **GET** /v2/alerts/{identifier}                                                | Get Alert                               |
| _OpsgenieSdk::AlertApi_                | [**get_attachment**](docs/AlertApi.md#get_attachment)                                                | **GET** /v2/alerts/{identifier}/attachments/{attachmentId}                     | Get Alert Attachment                    |
| _OpsgenieSdk::AlertApi_                | [**get_request_status**](docs/AlertApi.md#get_request_status)                                        | **GET** /v2/alerts/requests/{requestId}                                        | Get Request Status of Alert             |
| _OpsgenieSdk::AlertApi_                | [**get_saved_search**](docs/AlertApi.md#get_saved_search)                                            | **GET** /v2/alerts/saved-searches/{identifier}                                 | Get Saved Search                        |
| _OpsgenieSdk::AlertApi_                | [**list_alerts**](docs/AlertApi.md#list_alerts)                                                      | **GET** /v2/alerts                                                             | List Alerts                             |
| _OpsgenieSdk::AlertApi_                | [**list_attachments**](docs/AlertApi.md#list_attachments)                                            | **GET** /v2/alerts/{identifier}/attachments                                    | List Alert Attachments                  |
| _OpsgenieSdk::AlertApi_                | [**list_logs**](docs/AlertApi.md#list_logs)                                                          | **GET** /v2/alerts/{identifier}/logs                                           | List Alert Logs                         |
| _OpsgenieSdk::AlertApi_                | [**list_notes**](docs/AlertApi.md#list_notes)                                                        | **GET** /v2/alerts/{identifier}/notes                                          | List Alert Notes                        |
| _OpsgenieSdk::AlertApi_                | [**list_recipients**](docs/AlertApi.md#list_recipients)                                              | **GET** /v2/alerts/{identifier}/recipients                                     | List Alert Recipients                   |
| _OpsgenieSdk::AlertApi_                | [**list_saved_searches**](docs/AlertApi.md#list_saved_searches)                                      | **GET** /v2/alerts/saved-searches                                              | Lists Saved Searches                    |
| _OpsgenieSdk::AlertApi_                | [**remove_attachment**](docs/AlertApi.md#remove_attachment)                                          | **DELETE** /v2/alerts/{identifier}/attachments/{attachmentId}                  | Remove Alert Attachment                 |
| _OpsgenieSdk::AlertApi_                | [**remove_details**](docs/AlertApi.md#remove_details)                                                | **DELETE** /v2/alerts/{identifier}/details                                     | Remove Details                          |
| _OpsgenieSdk::AlertApi_                | [**remove_tags**](docs/AlertApi.md#remove_tags)                                                      | **DELETE** /v2/alerts/{identifier}/tags                                        | Remove Tags                             |
| _OpsgenieSdk::AlertApi_                | [**snooze_alert**](docs/AlertApi.md#snooze_alert)                                                    | **POST** /v2/alerts/{identifier}/snooze                                        | Snooze Alert                            |
| _OpsgenieSdk::AlertApi_                | [**un_acknowledge_alert**](docs/AlertApi.md#un_acknowledge_alert)                                    | **POST** /v2/alerts/{identifier}/unacknowledge                                 | UnAcknowledge Alert                     |
| _OpsgenieSdk::AlertApi_                | [**update_alert_description**](docs/AlertApi.md#update_alert_description)                            | **PUT** /v2/alerts/{identifier}/description                                    | Update Alert Description                |
| _OpsgenieSdk::AlertApi_                | [**update_alert_message**](docs/AlertApi.md#update_alert_message)                                    | **PUT** /v2/alerts/{identifier}/message                                        | Update Alert Message                    |
| _OpsgenieSdk::AlertApi_                | [**update_alert_priority**](docs/AlertApi.md#update_alert_priority)                                  | **PUT** /v2/alerts/{identifier}/priority                                       | Update Alert Priority                   |
| _OpsgenieSdk::AlertApi_                | [**update_saved_search**](docs/AlertApi.md#update_saved_search)                                      | **PATCH** /v2/alerts/saved-searches/{identifier}                               | Update Saved Search                     |
| _OpsgenieSdk::ContactApi_              | [**create_contact**](docs/ContactApi.md#create_contact)                                              | **POST** /v2/users/{identifier}/contacts                                       | Create Contact                          |
| _OpsgenieSdk::ContactApi_              | [**delete_contact**](docs/ContactApi.md#delete_contact)                                              | **DELETE** /v2/users/{identifier}/contacts/{contactId}                         | Delete Contact                          |
| _OpsgenieSdk::ContactApi_              | [**disable_contact**](docs/ContactApi.md#disable_contact)                                            | **POST** /v2/users/{identifier}/contacts/{contactId}/disable                   | Disable Contact                         |
| _OpsgenieSdk::ContactApi_              | [**enable_contact**](docs/ContactApi.md#enable_contact)                                              | **POST** /v2/users/{identifier}/contacts/{contactId}/enable                    | Enable Contact                          |
| _OpsgenieSdk::ContactApi_              | [**get_contact**](docs/ContactApi.md#get_contact)                                                    | **GET** /v2/users/{identifier}/contacts/{contactId}                            | Get Contact                             |
| _OpsgenieSdk::ContactApi_              | [**list_contacts**](docs/ContactApi.md#list_contacts)                                                | **GET** /v2/users/{identifier}/contacts                                        | List Contacts                           |
| _OpsgenieSdk::ContactApi_              | [**update_contact**](docs/ContactApi.md#update_contact)                                              | **PATCH** /v2/users/{identifier}/contacts/{contactId}                          | Update Contact (Partial)                |
| _OpsgenieSdk::CustomUserRoleApi_       | [**create_custom_user_role**](docs/CustomUserRoleApi.md#create_custom_user_role)                     | **POST** /v2/roles                                                             | Create Custom User Role                 |
| _OpsgenieSdk::CustomUserRoleApi_       | [**delete_custom_user_role**](docs/CustomUserRoleApi.md#delete_custom_user_role)                     | **DELETE** /v2/roles/{identifier}                                              | Delete Custom User Role                 |
| _OpsgenieSdk::CustomUserRoleApi_       | [**get_custom_user_role**](docs/CustomUserRoleApi.md#get_custom_user_role)                           | **GET** /v2/roles/{identifier}                                                 | Get Custom User Role                    |
| _OpsgenieSdk::CustomUserRoleApi_       | [**list_custom_user_roles**](docs/CustomUserRoleApi.md#list_custom_user_roles)                       | **GET** /v2/roles                                                              | List Custom User Roles                  |
| _OpsgenieSdk::CustomUserRoleApi_       | [**update_custom_user_role**](docs/CustomUserRoleApi.md#update_custom_user_role)                     | **PUT** /v2/roles/{identifier}                                                 | Update Custom User Role                 |
| _OpsgenieSdk::DeprecatedPolicyApi_     | [**change_alert_policy_order**](docs/DeprecatedPolicyApi.md#change_alert_policy_order)               | **POST** /v1/policies/{policyId}/change-order                                  | Change Alert Policy Order               |
| _OpsgenieSdk::DeprecatedPolicyApi_     | [**create_alert_policy**](docs/DeprecatedPolicyApi.md#create_alert_policy)                           | **POST** /v1/policies                                                          | Create Alert Policy                     |
| _OpsgenieSdk::DeprecatedPolicyApi_     | [**delete_alert_policy**](docs/DeprecatedPolicyApi.md#delete_alert_policy)                           | **DELETE** /v1/policies/{policyId}                                             | Delete Alert Policy                     |
| _OpsgenieSdk::DeprecatedPolicyApi_     | [**disable_alert_policy**](docs/DeprecatedPolicyApi.md#disable_alert_policy)                         | **POST** /v1/policies/{policyId}/disable                                       | Disable Alert Policy                    |
| _OpsgenieSdk::DeprecatedPolicyApi_     | [**enable_alert_policy**](docs/DeprecatedPolicyApi.md#enable_alert_policy)                           | **POST** /v1/policies/{policyId}/enable                                        | Enable Alert Policy                     |
| _OpsgenieSdk::DeprecatedPolicyApi_     | [**get_alert_policy**](docs/DeprecatedPolicyApi.md#get_alert_policy)                                 | **GET** /v1/policies/{policyId}                                                | Get Alert Policy                        |
| _OpsgenieSdk::DeprecatedPolicyApi_     | [**list_alert_policies**](docs/DeprecatedPolicyApi.md#list_alert_policies)                           | **GET** /v1/policies                                                           | List Alert Policies                     |
| _OpsgenieSdk::DeprecatedPolicyApi_     | [**update_alert_policy**](docs/DeprecatedPolicyApi.md#update_alert_policy)                           | **PUT** /v1/policies/{policyId}                                                | Update Alert Policy                     |
| _OpsgenieSdk::EscalationApi_           | [**create_escalation**](docs/EscalationApi.md#create_escalation)                                     | **POST** /v2/escalations                                                       | Create Escalation                       |
| _OpsgenieSdk::EscalationApi_           | [**delete_escalation**](docs/EscalationApi.md#delete_escalation)                                     | **DELETE** /v2/escalations/{identifier}                                        | Delete Escalation                       |
| _OpsgenieSdk::EscalationApi_           | [**get_escalation**](docs/EscalationApi.md#get_escalation)                                           | **GET** /v2/escalations/{identifier}                                           | Get Escalation                          |
| _OpsgenieSdk::EscalationApi_           | [**list_escalations**](docs/EscalationApi.md#list_escalations)                                       | **GET** /v2/escalations                                                        | List Escalations                        |
| _OpsgenieSdk::EscalationApi_           | [**update_escalation**](docs/EscalationApi.md#update_escalation)                                     | **PATCH** /v2/escalations/{identifier}                                         | Update Escalation (Partial)             |
| _OpsgenieSdk::ForwardingRuleApi_       | [**create_forwarding_rule**](docs/ForwardingRuleApi.md#create_forwarding_rule)                       | **POST** /v2/forwarding-rules                                                  | Create Forwarding Rule                  |
| _OpsgenieSdk::ForwardingRuleApi_       | [**delete_forwarding_rule**](docs/ForwardingRuleApi.md#delete_forwarding_rule)                       | **DELETE** /v2/forwarding-rules/{identifier}                                   | Delete Forwarding Rule                  |
| _OpsgenieSdk::ForwardingRuleApi_       | [**get_forwarding_rule**](docs/ForwardingRuleApi.md#get_forwarding_rule)                             | **GET** /v2/forwarding-rules/{identifier}                                      | Get Forwarding Rule                     |
| _OpsgenieSdk::ForwardingRuleApi_       | [**list_forwarding_rules**](docs/ForwardingRuleApi.md#list_forwarding_rules)                         | **GET** /v2/forwarding-rules                                                   | List Forwarding Rules                   |
| _OpsgenieSdk::ForwardingRuleApi_       | [**update_forwarding_rule**](docs/ForwardingRuleApi.md#update_forwarding_rule)                       | **PUT** /v2/forwarding-rules/{identifier}                                      | Update Forwarding Rule                  |
| _OpsgenieSdk::HeartbeatApi_            | [**create_heartbeat**](docs/HeartbeatApi.md#create_heartbeat)                                        | **POST** /v2/heartbeats                                                        | Create Heartbeat                        |
| _OpsgenieSdk::HeartbeatApi_            | [**delete_heartbeat**](docs/HeartbeatApi.md#delete_heartbeat)                                        | **DELETE** /v2/heartbeats/{name}                                               | Delete Heartbeat                        |
| _OpsgenieSdk::HeartbeatApi_            | [**disable_heartbeat**](docs/HeartbeatApi.md#disable_heartbeat)                                      | **POST** /v2/heartbeats/{name}/disable                                         | Disable Heartbeat                       |
| _OpsgenieSdk::HeartbeatApi_            | [**enable_heartbeat**](docs/HeartbeatApi.md#enable_heartbeat)                                        | **POST** /v2/heartbeats/{name}/enable                                          | Enable Heartbeat                        |
| _OpsgenieSdk::HeartbeatApi_            | [**get_heartbeat**](docs/HeartbeatApi.md#get_heartbeat)                                              | **GET** /v2/heartbeats/{name}                                                  | Get Heartbeat                           |
| _OpsgenieSdk::HeartbeatApi_            | [**list_heart_beats**](docs/HeartbeatApi.md#list_heart_beats)                                        | **GET** /v2/heartbeats                                                         | List Heartbeats                         |
| _OpsgenieSdk::HeartbeatApi_            | [**ping**](docs/HeartbeatApi.md#ping)                                                                | **GET** /v2/heartbeats/{name}/ping                                             | Ping Heartbeat                          |
| _OpsgenieSdk::HeartbeatApi_            | [**update_heartbeat**](docs/HeartbeatApi.md#update_heartbeat)                                        | **PATCH** /v2/heartbeats/{name}                                                | Update Heartbeat (Partial)              |
| _OpsgenieSdk::IncidentApi_             | [**close_incident**](docs/IncidentApi.md#close_incident)                                             | **POST** /v1/incidents/{identifier}/close                                      | Close Incident                          |
| _OpsgenieSdk::IncidentApi_             | [**create_incident**](docs/IncidentApi.md#create_incident)                                           | **POST** /v1/incidents/create                                                  | Create Incident                         |
| _OpsgenieSdk::IncidentApi_             | [**delete_incident**](docs/IncidentApi.md#delete_incident)                                           | **DELETE** /v1/incidents/{identifier}                                          | Delete Incident                         |
| _OpsgenieSdk::IncidentApi_             | [**get_incident**](docs/IncidentApi.md#get_incident)                                                 | **GET** /v1/incidents/{identifier}                                             | Get Incident                            |
| _OpsgenieSdk::IncidentApi_             | [**get_incident_request_status**](docs/IncidentApi.md#get_incident_request_status)                   | **GET** /v1/incidents/requests/{requestId}                                     | Get Request Status of Incident          |
| _OpsgenieSdk::IncidentApi_             | [**list_incidents**](docs/IncidentApi.md#list_incidents)                                             | **GET** /v1/incidents/                                                         | List incidents                          |
| _OpsgenieSdk::IntegrationApi_          | [**authenticate_integration**](docs/IntegrationApi.md#authenticate_integration)                      | **POST** /v2/integrations/authenticate                                         | Authenticate Integration                |
| _OpsgenieSdk::IntegrationApi_          | [**create_integration**](docs/IntegrationApi.md#create_integration)                                  | **POST** /v2/integrations                                                      | Create Integration                      |
| _OpsgenieSdk::IntegrationApi_          | [**delete_integration**](docs/IntegrationApi.md#delete_integration)                                  | **DELETE** /v2/integrations/{id}                                               | Delete Integration                      |
| _OpsgenieSdk::IntegrationApi_          | [**disable_integration**](docs/IntegrationApi.md#disable_integration)                                | **POST** /v2/integrations/{id}/disable                                         | Disable Integration                     |
| _OpsgenieSdk::IntegrationApi_          | [**enable_integration**](docs/IntegrationApi.md#enable_integration)                                  | **POST** /v2/integrations/{id}/enable                                          | Enable Integration                      |
| _OpsgenieSdk::IntegrationApi_          | [**get_integration**](docs/IntegrationApi.md#get_integration)                                        | **GET** /v2/integrations/{id}                                                  | Get Integration                         |
| _OpsgenieSdk::IntegrationApi_          | [**list_integrations**](docs/IntegrationApi.md#list_integrations)                                    | **GET** /v2/integrations                                                       | List Integrations                       |
| _OpsgenieSdk::IntegrationApi_          | [**update_integration**](docs/IntegrationApi.md#update_integration)                                  | **PUT** /v2/integrations/{id}                                                  | Update Integration                      |
| _OpsgenieSdk::IntegrationActionApi_    | [**create_integration_action**](docs/IntegrationActionApi.md#create_integration_action)              | **POST** /v2/integrations/{id}/actions                                         | Create Integration Action               |
| _OpsgenieSdk::IntegrationActionApi_    | [**list_integration_actions**](docs/IntegrationActionApi.md#list_integration_actions)                | **GET** /v2/integrations/{id}/actions                                          | List Integration Actions                |
| _OpsgenieSdk::IntegrationActionApi_    | [**update_integration_actions**](docs/IntegrationActionApi.md#update_integration_actions)            | **PUT** /v2/integrations/{id}/actions                                          | Update Integration Actions              |
| _OpsgenieSdk::MaintenanceApi_          | [**cancel_maintenance**](docs/MaintenanceApi.md#cancel_maintenance)                                  | **POST** /v1/maintenance/{id}/cancel                                           | Cancel Maintenance                      |
| _OpsgenieSdk::MaintenanceApi_          | [**create_maintenance**](docs/MaintenanceApi.md#create_maintenance)                                  | **POST** /v1/maintenance                                                       | Create Maintenance                      |
| _OpsgenieSdk::MaintenanceApi_          | [**delete_maintenance**](docs/MaintenanceApi.md#delete_maintenance)                                  | **DELETE** /v1/maintenance/{id}                                                | Delete Maintenance                      |
| _OpsgenieSdk::MaintenanceApi_          | [**get_maintenance**](docs/MaintenanceApi.md#get_maintenance)                                        | **GET** /v1/maintenance/{id}                                                   | Get Maintenance                         |
| _OpsgenieSdk::MaintenanceApi_          | [**list_maintenance**](docs/MaintenanceApi.md#list_maintenance)                                      | **GET** /v1/maintenance                                                        | List Maintenance                        |
| _OpsgenieSdk::MaintenanceApi_          | [**update_maintenance**](docs/MaintenanceApi.md#update_maintenance)                                  | **PUT** /v1/maintenance/{id}                                                   | Update Maintenance                      |
| _OpsgenieSdk::NotificationRuleApi_     | [**change_notification_rule_order**](docs/NotificationRuleApi.md#change_notification_rule_order)     | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/change-order       | Change order of Notification Rule       |
| _OpsgenieSdk::NotificationRuleApi_     | [**create_notification_rule**](docs/NotificationRuleApi.md#create_notification_rule)                 | **POST** /v2/users/{identifier}/notification-rules                             | Create Notification Rule                |
| _OpsgenieSdk::NotificationRuleApi_     | [**delete_notification_rule**](docs/NotificationRuleApi.md#delete_notification_rule)                 | **DELETE** /v2/users/{identifier}/notification-rules/{ruleId}                  | Delete Notification Rule                |
| _OpsgenieSdk::NotificationRuleApi_     | [**disable_notification_rule**](docs/NotificationRuleApi.md#disable_notification_rule)               | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/disable            | Disable Notification Rule               |
| _OpsgenieSdk::NotificationRuleApi_     | [**enable_notification_rule**](docs/NotificationRuleApi.md#enable_notification_rule)                 | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/enable             | Enable Notification Rule                |
| _OpsgenieSdk::NotificationRuleApi_     | [**get_notification_rule**](docs/NotificationRuleApi.md#get_notification_rule)                       | **GET** /v2/users/{identifier}/notification-rules/{ruleId}                     | Get Notification Rule                   |
| _OpsgenieSdk::NotificationRuleApi_     | [**list_notification_rules**](docs/NotificationRuleApi.md#list_notification_rules)                   | **GET** /v2/users/{identifier}/notification-rules                              | List Notification Rules                 |
| _OpsgenieSdk::NotificationRuleApi_     | [**update_notification_rule**](docs/NotificationRuleApi.md#update_notification_rule)                 | **PATCH** /v2/users/{identifier}/notification-rules/{ruleId}                   | Update Notification Rule (Partial)      |
| _OpsgenieSdk::NotificationRuleStepApi_ | [**create_notification_rule_step**](docs/NotificationRuleStepApi.md#create_notification_rule_step)   | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/steps              | Create Notification Rule Step           |
| _OpsgenieSdk::NotificationRuleStepApi_ | [**delete_notification_rule_step**](docs/NotificationRuleStepApi.md#delete_notification_rule_step)   | **DELETE** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id}       | Delete Notification Rule Step           |
| _OpsgenieSdk::NotificationRuleStepApi_ | [**disable_notification_rule_step**](docs/NotificationRuleStepApi.md#disable_notification_rule_step) | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id}/disable | Disable Notification Rule Step          |
| _OpsgenieSdk::NotificationRuleStepApi_ | [**enable_notification_rule_step**](docs/NotificationRuleStepApi.md#enable_notification_rule_step)   | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id}/enable  | Enable Notification Rule Step           |
| _OpsgenieSdk::NotificationRuleStepApi_ | [**get_notification_rule_step**](docs/NotificationRuleStepApi.md#get_notification_rule_step)         | **GET** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id}          | Get Notification Rule Step              |
| _OpsgenieSdk::NotificationRuleStepApi_ | [**list_notification_rule_steps**](docs/NotificationRuleStepApi.md#list_notification_rule_steps)     | **GET** /v2/users/{identifier}/notification-rules/{ruleId}/steps               | List Notification Rule Steps            |
| _OpsgenieSdk::NotificationRuleStepApi_ | [**update_notification_rule_step**](docs/NotificationRuleStepApi.md#update_notification_rule_step)   | **PATCH** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id}        | Update Notification Rule Step (Partial) |
| _OpsgenieSdk::PolicyApi_               | [**change_policy_order**](docs/PolicyApi.md#change_policy_order)                                     | **POST** /v2/policies/{policyId}/change-order                                  | Change Policy Order                     |
| _OpsgenieSdk::PolicyApi_               | [**create_policy**](docs/PolicyApi.md#create_policy)                                                 | **POST** /v2/policies                                                          | Create Policy                           |
| _OpsgenieSdk::PolicyApi_               | [**delete_policy**](docs/PolicyApi.md#delete_policy)                                                 | **DELETE** /v2/policies/{policyId}                                             | Delete Policy                           |
| _OpsgenieSdk::PolicyApi_               | [**disable_policy**](docs/PolicyApi.md#disable_policy)                                               | **POST** /v2/policies/{policyId}/disable                                       | Disable Policy                          |
| _OpsgenieSdk::PolicyApi_               | [**enable_policy**](docs/PolicyApi.md#enable_policy)                                                 | **POST** /v2/policies/{policyId}/enable                                        | Enable Policy                           |
| _OpsgenieSdk::PolicyApi_               | [**get_policy**](docs/PolicyApi.md#get_policy)                                                       | **GET** /v2/policies/{policyId}                                                | Get Policy                              |
| _OpsgenieSdk::PolicyApi_               | [**list_alert_policies**](docs/PolicyApi.md#list_alert_policies)                                     | **GET** /v2/policies/alert                                                     | List Alert Policies                     |
| _OpsgenieSdk::PolicyApi_               | [**list_notification_policies**](docs/PolicyApi.md#list_notification_policies)                       | **GET** /v2/policies/notification                                              | List Notification Policies              |
| _OpsgenieSdk::PolicyApi_               | [**update_policy**](docs/PolicyApi.md#update_policy)                                                 | **PUT** /v2/policies/{policyId}                                                | Update Policy                           |
| _OpsgenieSdk::ScheduleApi_             | [**create_schedule**](docs/ScheduleApi.md#create_schedule)                                           | **POST** /v2/schedules                                                         | Create Schedule                         |
| _OpsgenieSdk::ScheduleApi_             | [**delete_schedule**](docs/ScheduleApi.md#delete_schedule)                                           | **DELETE** /v2/schedules/{identifier}                                          | Delete Schedule                         |
| _OpsgenieSdk::ScheduleApi_             | [**export_schedule**](docs/ScheduleApi.md#export_schedule)                                           | **GET** /v2/schedules/{identifier}.ics                                         | Export Schedule                         |
| _OpsgenieSdk::ScheduleApi_             | [**get_schedule**](docs/ScheduleApi.md#get_schedule)                                                 | **GET** /v2/schedules/{identifier}                                             | Get Schedule                            |
| _OpsgenieSdk::ScheduleApi_             | [**get_schedule_timeline**](docs/ScheduleApi.md#get_schedule_timeline)                               | **GET** /v2/schedules/{identifier}/timeline                                    | Get Schedule Timeline                   |
| _OpsgenieSdk::ScheduleApi_             | [**list_schedules**](docs/ScheduleApi.md#list_schedules)                                             | **GET** /v2/schedules                                                          | List Schedules                          |
| _OpsgenieSdk::ScheduleApi_             | [**update_schedule**](docs/ScheduleApi.md#update_schedule)                                           | **PATCH** /v2/schedules/{identifier}                                           | Update Schedule (Partial)               |
| _OpsgenieSdk::ScheduleOverrideApi_     | [**create_schedule_override**](docs/ScheduleOverrideApi.md#create_schedule_override)                 | **POST** /v2/schedules/{identifier}/overrides                                  | Create Schedule Override                |
| _OpsgenieSdk::ScheduleOverrideApi_     | [**delete_schedule_override**](docs/ScheduleOverrideApi.md#delete_schedule_override)                 | **DELETE** /v2/schedules/{identifier}/overrides/{alias}                        | Delete Schedule Override                |
| _OpsgenieSdk::ScheduleOverrideApi_     | [**get_schedule_override**](docs/ScheduleOverrideApi.md#get_schedule_override)                       | **GET** /v2/schedules/{identifier}/overrides/{alias}                           | Get Schedule Override                   |
| _OpsgenieSdk::ScheduleOverrideApi_     | [**list_schedule_override**](docs/ScheduleOverrideApi.md#list_schedule_override)                     | **GET** /v2/schedules/{identifier}/overrides                                   | List Schedule Overrides                 |
| _OpsgenieSdk::ScheduleOverrideApi_     | [**update_schedule_override**](docs/ScheduleOverrideApi.md#update_schedule_override)                 | **PUT** /v2/schedules/{identifier}/overrides/{alias}                           | Update Schedule Override                |
| _OpsgenieSdk::ScheduleRotationApi_     | [**create_schedule_rotation**](docs/ScheduleRotationApi.md#create_schedule_rotation)                 | **POST** /v2/schedules/{identifier}/rotations                                  | Create Schedule Rotation                |
| _OpsgenieSdk::ScheduleRotationApi_     | [**delete_schedule_rotation**](docs/ScheduleRotationApi.md#delete_schedule_rotation)                 | **DELETE** /v2/schedules/{identifier}/rotations/{id}                           | Delete Schedule Rotation                |
| _OpsgenieSdk::ScheduleRotationApi_     | [**get_schedule_rotation**](docs/ScheduleRotationApi.md#get_schedule_rotation)                       | **GET** /v2/schedules/{identifier}/rotations/{id}                              | Get Schedule Rotation                   |
| _OpsgenieSdk::ScheduleRotationApi_     | [**list_schedule_rotations**](docs/ScheduleRotationApi.md#list_schedule_rotations)                   | **GET** /v2/schedules/{identifier}/rotations                                   | List Schedule Rotations                 |
| _OpsgenieSdk::ScheduleRotationApi_     | [**update_schedule_rotation**](docs/ScheduleRotationApi.md#update_schedule_rotation)                 | **PATCH** /v2/schedules/{identifier}/rotations/{id}                            | Update Schedule Rotation (Partial)      |
| _OpsgenieSdk::TeamApi_                 | [**create_team**](docs/TeamApi.md#create_team)                                                       | **POST** /v2/teams                                                             | Create Team                             |
| _OpsgenieSdk::TeamApi_                 | [**delete_team**](docs/TeamApi.md#delete_team)                                                       | **DELETE** /v2/teams/{identifier}                                              | Delete Team                             |
| _OpsgenieSdk::TeamApi_                 | [**get_team**](docs/TeamApi.md#get_team)                                                             | **GET** /v2/teams/{identifier}                                                 | Get Team                                |
| _OpsgenieSdk::TeamApi_                 | [**list_team_logs**](docs/TeamApi.md#list_team_logs)                                                 | **GET** /v2/teams/{identifier}/logs                                            | List Team Logs                          |
| _OpsgenieSdk::TeamApi_                 | [**list_teams**](docs/TeamApi.md#list_teams)                                                         | **GET** /v2/teams                                                              | List Teams                              |
| _OpsgenieSdk::TeamApi_                 | [**update_team**](docs/TeamApi.md#update_team)                                                       | **PATCH** /v2/teams/{identifier}                                               | Update Team (Partial)                   |
| _OpsgenieSdk::TeamMemberApi_           | [**add_team_member**](docs/TeamMemberApi.md#add_team_member)                                         | **POST** /v2/teams/{identifier}/members                                        | Add Team Member                         |
| _OpsgenieSdk::TeamMemberApi_           | [**delete_team_member**](docs/TeamMemberApi.md#delete_team_member)                                   | **DELETE** /v2/teams/{identifier}/members/{memberIdentifier}                   | Delete Team Member                      |
| _OpsgenieSdk::TeamRoleApi_             | [**create_team_role**](docs/TeamRoleApi.md#create_team_role)                                         | **POST** /v2/teams/{identifier}/roles                                          | Create Team Role                        |
| _OpsgenieSdk::TeamRoleApi_             | [**delete_team_role**](docs/TeamRoleApi.md#delete_team_role)                                         | **DELETE** /v2/teams/{identifier}/roles/{teamRoleIdentifier}                   | Delete Team Role                        |
| _OpsgenieSdk::TeamRoleApi_             | [**get_team_role**](docs/TeamRoleApi.md#get_team_role)                                               | **GET** /v2/teams/{identifier}/roles/{teamRoleIdentifier}                      | Get Team Role                           |
| _OpsgenieSdk::TeamRoleApi_             | [**list_team_roles**](docs/TeamRoleApi.md#list_team_roles)                                           | **GET** /v2/teams/{identifier}/roles                                           | List Team Roles                         |
| _OpsgenieSdk::TeamRoleApi_             | [**update_team_role**](docs/TeamRoleApi.md#update_team_role)                                         | **PATCH** /v2/teams/{identifier}/roles/{teamRoleIdentifier}                    | Update Team Role (Partial)              |
| _OpsgenieSdk::TeamRoutingRuleApi_      | [**change_team_routing_rule_order**](docs/TeamRoutingRuleApi.md#change_team_routing_rule_order)      | **POST** /v2/teams/{identifier}/routing-rules/{id}/change-order                | Change Team Routing Rule Order          |
| _OpsgenieSdk::TeamRoutingRuleApi_      | [**create_team_routing_rule**](docs/TeamRoutingRuleApi.md#create_team_routing_rule)                  | **POST** /v2/teams/{identifier}/routing-rules                                  | Create Team Routing Rule                |
| _OpsgenieSdk::TeamRoutingRuleApi_      | [**delete_team_routing_rule**](docs/TeamRoutingRuleApi.md#delete_team_routing_rule)                  | **DELETE** /v2/teams/{identifier}/routing-rules/{id}                           | Delete Team Routing Rule                |
| _OpsgenieSdk::TeamRoutingRuleApi_      | [**get_team_routing_rule**](docs/TeamRoutingRuleApi.md#get_team_routing_rule)                        | **GET** /v2/teams/{identifier}/routing-rules/{id}                              | Get Team Routing Rule                   |
| _OpsgenieSdk::TeamRoutingRuleApi_      | [**list_team_routing_rules**](docs/TeamRoutingRuleApi.md#list_team_routing_rules)                    | **GET** /v2/teams/{identifier}/routing-rules                                   | List Team Routing Rules                 |
| _OpsgenieSdk::TeamRoutingRuleApi_      | [**update_team_routing_rule**](docs/TeamRoutingRuleApi.md#update_team_routing_rule)                  | **PATCH** /v2/teams/{identifier}/routing-rules/{id}                            | Update Team Routing Rule (Partial)      |
| _OpsgenieSdk::UserApi_                 | [**create_user**](docs/UserApi.md#create_user)                                                       | **POST** /v2/users                                                             | Create User                             |
| _OpsgenieSdk::UserApi_                 | [**delete_user**](docs/UserApi.md#delete_user)                                                       | **DELETE** /v2/users/{identifier}                                              | Delete User                             |
| _OpsgenieSdk::UserApi_                 | [**get_user**](docs/UserApi.md#get_user)                                                             | **GET** /v2/users/{identifier}                                                 | Get User                                |
| _OpsgenieSdk::UserApi_                 | [**list_user_escalations**](docs/UserApi.md#list_user_escalations)                                   | **GET** /v2/users/{identifier}/escalations                                     | List User Escalations                   |
| _OpsgenieSdk::UserApi_                 | [**list_user_forwarding_rules**](docs/UserApi.md#list_user_forwarding_rules)                         | **GET** /v2/users/{identifier}/forwarding-rules                                | List User Forwarding Rules              |
| _OpsgenieSdk::UserApi_                 | [**list_user_schedules**](docs/UserApi.md#list_user_schedules)                                       | **GET** /v2/users/{identifier}/schedules                                       | List User Schedules                     |
| _OpsgenieSdk::UserApi_                 | [**list_user_teams**](docs/UserApi.md#list_user_teams)                                               | **GET** /v2/users/{identifier}/teams                                           | List User Teams                         |
| _OpsgenieSdk::UserApi_                 | [**list_users**](docs/UserApi.md#list_users)                                                         | **GET** /v2/users                                                              | List users                              |
| _OpsgenieSdk::UserApi_                 | [**update_user**](docs/UserApi.md#update_user)                                                       | **PATCH** /v2/users/{identifier}                                               | Update User (Partial)                   |
| _OpsgenieSdk::WhoIsOnCallApi_          | [**export_on_call_user**](docs/WhoIsOnCallApi.md#export_on_call_user)                                | **GET** /v2/schedules/on-calls/{identifier}.ics                                | Export On-Call User                     |
| _OpsgenieSdk::WhoIsOnCallApi_          | [**get_next_on_calls**](docs/WhoIsOnCallApi.md#get_next_on_calls)                                    | **GET** /v2/schedules/{identifier}/next-on-calls                               | Get Next On Calls                       |
| _OpsgenieSdk::WhoIsOnCallApi_          | [**get_on_calls**](docs/WhoIsOnCallApi.md#get_on_calls)                                              | **GET** /v2/schedules/{identifier}/on-calls                                    | Get On Calls                            |
| _OpsgenieSdk::WhoIsOnCallApi_          | [**list_on_calls**](docs/WhoIsOnCallApi.md#list_on_calls)                                            | **GET** /v2/schedules/on-calls                                                 | List On Calls                           |

## Documentation for Models

- [OpsgenieSdk::AccountInfo](docs/AccountInfo.md)
- [OpsgenieSdk::AccountPlan](docs/AccountPlan.md)
- [OpsgenieSdk::AckIntegrationAction](docs/AckIntegrationAction.md)
- [OpsgenieSdk::AcknowledgeAlertPayload](docs/AcknowledgeAlertPayload.md)
- [OpsgenieSdk::ActionCategorized](docs/ActionCategorized.md)
- [OpsgenieSdk::ActionMapping](docs/ActionMapping.md)
- [OpsgenieSdk::AddDetailsToAlertPayload](docs/AddDetailsToAlertPayload.md)
- [OpsgenieSdk::AddNoteIntegrationAction](docs/AddNoteIntegrationAction.md)
- [OpsgenieSdk::AddNoteToAlertPayload](docs/AddNoteToAlertPayload.md)
- [OpsgenieSdk::AddResponderToAlertPayload](docs/AddResponderToAlertPayload.md)
- [OpsgenieSdk::AddTagsToAlertPayload](docs/AddTagsToAlertPayload.md)
- [OpsgenieSdk::AddTeamMemberPayload](docs/AddTeamMemberPayload.md)
- [OpsgenieSdk::AddTeamToAlertPayload](docs/AddTeamToAlertPayload.md)
- [OpsgenieSdk::AirbrakeIntegration](docs/AirbrakeIntegration.md)
- [OpsgenieSdk::Alert](docs/Alert.md)
- [OpsgenieSdk::AlertActionPayload](docs/AlertActionPayload.md)
- [OpsgenieSdk::AlertAttachment](docs/AlertAttachment.md)
- [OpsgenieSdk::AlertAttachmentMeta](docs/AlertAttachmentMeta.md)
- [OpsgenieSdk::AlertFilter](docs/AlertFilter.md)
- [OpsgenieSdk::AlertIntegration](docs/AlertIntegration.md)
- [OpsgenieSdk::AlertLog](docs/AlertLog.md)
- [OpsgenieSdk::AlertLogicIntegration](docs/AlertLogicIntegration.md)
- [OpsgenieSdk::AlertNote](docs/AlertNote.md)
- [OpsgenieSdk::AlertPaging](docs/AlertPaging.md)
- [OpsgenieSdk::AlertPolicy](docs/AlertPolicy.md)
- [OpsgenieSdk::AlertRecipient](docs/AlertRecipient.md)
- [OpsgenieSdk::AlertReport](docs/AlertReport.md)
- [OpsgenieSdk::AlertRequestStatus](docs/AlertRequestStatus.md)
- [OpsgenieSdk::AlertSiteIntegration](docs/AlertSiteIntegration.md)
- [OpsgenieSdk::AlertTeamMeta](docs/AlertTeamMeta.md)
- [OpsgenieSdk::AlertUserMeta](docs/AlertUserMeta.md)
- [OpsgenieSdk::AllRecipient](docs/AllRecipient.md)
- [OpsgenieSdk::AmazonCloudTrailIntegration](docs/AmazonCloudTrailIntegration.md)
- [OpsgenieSdk::AmazonEc2AutoScalingIntegration](docs/AmazonEc2AutoScalingIntegration.md)
- [OpsgenieSdk::AmazonRdsIntegration](docs/AmazonRdsIntegration.md)
- [OpsgenieSdk::AmazonRoute53HealthCheckIntegration](docs/AmazonRoute53HealthCheckIntegration.md)
- [OpsgenieSdk::AmazonSecurityHubIntegration](docs/AmazonSecurityHubIntegration.md)
- [OpsgenieSdk::AmazonSesIntegration](docs/AmazonSesIntegration.md)
- [OpsgenieSdk::AmazonSnsCallback](docs/AmazonSnsCallback.md)
- [OpsgenieSdk::AmazonSnsIntegration](docs/AmazonSnsIntegration.md)
- [OpsgenieSdk::AmazonSnsOutgoingIntegration](docs/AmazonSnsOutgoingIntegration.md)
- [OpsgenieSdk::ApiIntegration](docs/ApiIntegration.md)
- [OpsgenieSdk::ApicaIntegration](docs/ApicaIntegration.md)
- [OpsgenieSdk::ApimetricsIntegration](docs/ApimetricsIntegration.md)
- [OpsgenieSdk::AppDynamicsIntegration](docs/AppDynamicsIntegration.md)
- [OpsgenieSdk::AppOpticsIntegration](docs/AppOpticsIntegration.md)
- [OpsgenieSdk::AppSignalIntegration](docs/AppSignalIntegration.md)
- [OpsgenieSdk::AppSignalV2Integration](docs/AppSignalV2Integration.md)
- [OpsgenieSdk::AssignAlertPayload](docs/AssignAlertPayload.md)
- [OpsgenieSdk::AtatusIntegration](docs/AtatusIntegration.md)
- [OpsgenieSdk::AtlassianBambooIntegration](docs/AtlassianBambooIntegration.md)
- [OpsgenieSdk::AuthenticateIntegrationPayload](docs/AuthenticateIntegrationPayload.md)
- [OpsgenieSdk::AutoCloseAction](docs/AutoCloseAction.md)
- [OpsgenieSdk::AutoRestartAction](docs/AutoRestartAction.md)
- [OpsgenieSdk::AutoTaskEmailIntegration](docs/AutoTaskEmailIntegration.md)
- [OpsgenieSdk::AutotaskAEMEmailIntegration](docs/AutotaskAEMEmailIntegration.md)
- [OpsgenieSdk::AzureAutoScaleIntegration](docs/AzureAutoScaleIntegration.md)
- [OpsgenieSdk::AzureIntegration](docs/AzureIntegration.md)
- [OpsgenieSdk::AzureOMSIntegration](docs/AzureOMSIntegration.md)
- [OpsgenieSdk::AzureResourceHealthIntegration](docs/AzureResourceHealthIntegration.md)
- [OpsgenieSdk::AzureServiceHealthIntegration](docs/AzureServiceHealthIntegration.md)
- [OpsgenieSdk::BMCFootPrintsV11Callback](docs/BMCFootPrintsV11Callback.md)
- [OpsgenieSdk::BMCFootPrintsV11Integration](docs/BMCFootPrintsV11Integration.md)
- [OpsgenieSdk::BMCFootPrintsV12Callback](docs/BMCFootPrintsV12Callback.md)
- [OpsgenieSdk::BMCFootPrintsV12Integration](docs/BMCFootPrintsV12Integration.md)
- [OpsgenieSdk::BMCRemedyCallback](docs/BMCRemedyCallback.md)
- [OpsgenieSdk::BMCRemedyForceIntegration](docs/BMCRemedyForceIntegration.md)
- [OpsgenieSdk::BMCRemedyIntegration](docs/BMCRemedyIntegration.md)
- [OpsgenieSdk::BMCRemedyOnDemandCallback](docs/BMCRemedyOnDemandCallback.md)
- [OpsgenieSdk::BMCRemedyOnDemandIntegration](docs/BMCRemedyOnDemandIntegration.md)
- [OpsgenieSdk::BaseAlert](docs/BaseAlert.md)
- [OpsgenieSdk::BaseIncident](docs/BaseIncident.md)
- [OpsgenieSdk::BaseIncomingFeature](docs/BaseIncomingFeature.md)
- [OpsgenieSdk::BaseIntegrationAction](docs/BaseIntegrationAction.md)
- [OpsgenieSdk::BaseResponse](docs/BaseResponse.md)
- [OpsgenieSdk::BaseResponseWithExpandable](docs/BaseResponseWithExpandable.md)
- [OpsgenieSdk::BaseWebhookCallback](docs/BaseWebhookCallback.md)
- [OpsgenieSdk::BidirectionalCallback](docs/BidirectionalCallback.md)
- [OpsgenieSdk::BidirectionalCallbackNew](docs/BidirectionalCallbackNew.md)
- [OpsgenieSdk::BigPandaIntegration](docs/BigPandaIntegration.md)
- [OpsgenieSdk::BitbucketIntegration](docs/BitbucketIntegration.md)
- [OpsgenieSdk::BlueMatadorIntegration](docs/BlueMatadorIntegration.md)
- [OpsgenieSdk::BoundaryIntegration](docs/BoundaryIntegration.md)
- [OpsgenieSdk::CallbackCondition](docs/CallbackCondition.md)
- [OpsgenieSdk::CampfireCallback](docs/CampfireCallback.md)
- [OpsgenieSdk::CampfireIntegration](docs/CampfireIntegration.md)
- [OpsgenieSdk::CatchpointIntegration](docs/CatchpointIntegration.md)
- [OpsgenieSdk::ChangeNotificationRuleOrderPayload](docs/ChangeNotificationRuleOrderPayload.md)
- [OpsgenieSdk::ChangePolicyOrderPayload](docs/ChangePolicyOrderPayload.md)
- [OpsgenieSdk::ChangeTeamRoutingRuleOrderPayload](docs/ChangeTeamRoutingRuleOrderPayload.md)
- [OpsgenieSdk::CheckMKIntegration](docs/CheckMKIntegration.md)
- [OpsgenieSdk::CherwellCallback](docs/CherwellCallback.md)
- [OpsgenieSdk::CherwellIntegration](docs/CherwellIntegration.md)
- [OpsgenieSdk::CircleCiIntegration](docs/CircleCiIntegration.md)
- [OpsgenieSdk::CirconusCallback](docs/CirconusCallback.md)
- [OpsgenieSdk::CirconusIntegration](docs/CirconusIntegration.md)
- [OpsgenieSdk::CloseAlertPayload](docs/CloseAlertPayload.md)
- [OpsgenieSdk::CloseIncidentPayload](docs/CloseIncidentPayload.md)
- [OpsgenieSdk::CloseIntegrationAction](docs/CloseIntegrationAction.md)
- [OpsgenieSdk::CloudMonixIntegration](docs/CloudMonixIntegration.md)
- [OpsgenieSdk::CloudSploitIntegration](docs/CloudSploitIntegration.md)
- [OpsgenieSdk::CloudWatchEventsIntegration](docs/CloudWatchEventsIntegration.md)
- [OpsgenieSdk::CloudWatchIntegration](docs/CloudWatchIntegration.md)
- [OpsgenieSdk::CodeshipIntegration](docs/CodeshipIntegration.md)
- [OpsgenieSdk::CommonIntegrationAction](docs/CommonIntegrationAction.md)
- [OpsgenieSdk::ComposeIntegration](docs/ComposeIntegration.md)
- [OpsgenieSdk::Condition](docs/Condition.md)
- [OpsgenieSdk::ConnectWiseAutomateIntegration](docs/ConnectWiseAutomateIntegration.md)
- [OpsgenieSdk::ConnectWiseCallback](docs/ConnectWiseCallback.md)
- [OpsgenieSdk::ConnectWiseIntegration](docs/ConnectWiseIntegration.md)
- [OpsgenieSdk::ConnectWiseManageCallback](docs/ConnectWiseManageCallback.md)
- [OpsgenieSdk::ConnectWiseManageIntegration](docs/ConnectWiseManageIntegration.md)
- [OpsgenieSdk::ConnectWiseManageV2Callback](docs/ConnectWiseManageV2Callback.md)
- [OpsgenieSdk::ConnectWiseManageV2Integration](docs/ConnectWiseManageV2Integration.md)
- [OpsgenieSdk::ConsulIntegration](docs/ConsulIntegration.md)
- [OpsgenieSdk::Contact](docs/Contact.md)
- [OpsgenieSdk::ContactMeta](docs/ContactMeta.md)
- [OpsgenieSdk::ContactStatus](docs/ContactStatus.md)
- [OpsgenieSdk::ContactWithApplyOrder](docs/ContactWithApplyOrder.md)
- [OpsgenieSdk::CopperEggIntegration](docs/CopperEggIntegration.md)
- [OpsgenieSdk::CrashlyticsIntegration](docs/CrashlyticsIntegration.md)
- [OpsgenieSdk::CreateAlertPayload](docs/CreateAlertPayload.md)
- [OpsgenieSdk::CreateContactPayload](docs/CreateContactPayload.md)
- [OpsgenieSdk::CreateCustomUserRolePayload](docs/CreateCustomUserRolePayload.md)
- [OpsgenieSdk::CreateEscalationPayload](docs/CreateEscalationPayload.md)
- [OpsgenieSdk::CreateForwardingRulePayload](docs/CreateForwardingRulePayload.md)
- [OpsgenieSdk::CreateForwardingRuleResponse](docs/CreateForwardingRuleResponse.md)
- [OpsgenieSdk::CreateHeartbeatPayload](docs/CreateHeartbeatPayload.md)
- [OpsgenieSdk::CreateHeartbeatResponse](docs/CreateHeartbeatResponse.md)
- [OpsgenieSdk::CreateIncidentPayload](docs/CreateIncidentPayload.md)
- [OpsgenieSdk::CreateIntegrationAction](docs/CreateIntegrationAction.md)
- [OpsgenieSdk::CreateIntegrationActionsResponse](docs/CreateIntegrationActionsResponse.md)
- [OpsgenieSdk::CreateIntegrationResponse](docs/CreateIntegrationResponse.md)
- [OpsgenieSdk::CreateMaintenancePayload](docs/CreateMaintenancePayload.md)
- [OpsgenieSdk::CreateMaintenanceResponse](docs/CreateMaintenanceResponse.md)
- [OpsgenieSdk::CreateNotificationRulePayload](docs/CreateNotificationRulePayload.md)
- [OpsgenieSdk::CreateNotificationRuleResponse](docs/CreateNotificationRuleResponse.md)
- [OpsgenieSdk::CreateNotificationRuleStepPayload](docs/CreateNotificationRuleStepPayload.md)
- [OpsgenieSdk::CreatePolicyResponse](docs/CreatePolicyResponse.md)
- [OpsgenieSdk::CreateSavedSearchPayload](docs/CreateSavedSearchPayload.md)
- [OpsgenieSdk::CreateSavedSearchResponse](docs/CreateSavedSearchResponse.md)
- [OpsgenieSdk::CreateScheduleOverridePayload](docs/CreateScheduleOverridePayload.md)
- [OpsgenieSdk::CreateScheduleOverrideResponse](docs/CreateScheduleOverrideResponse.md)
- [OpsgenieSdk::CreateSchedulePayload](docs/CreateSchedulePayload.md)
- [OpsgenieSdk::CreateScheduleResponse](docs/CreateScheduleResponse.md)
- [OpsgenieSdk::CreateScheduleRotationPayload](docs/CreateScheduleRotationPayload.md)
- [OpsgenieSdk::CreateTeamPayload](docs/CreateTeamPayload.md)
- [OpsgenieSdk::CreateTeamRolePayload](docs/CreateTeamRolePayload.md)
- [OpsgenieSdk::CreateTeamRoutingRulePayload](docs/CreateTeamRoutingRulePayload.md)
- [OpsgenieSdk::CreateUserPayload](docs/CreateUserPayload.md)
- [OpsgenieSdk::CustomUserRole](docs/CustomUserRole.md)
- [OpsgenieSdk::DatadogCallback](docs/DatadogCallback.md)
- [OpsgenieSdk::DatadogIntegration](docs/DatadogIntegration.md)
- [OpsgenieSdk::DataloopIOIntegration](docs/DataloopIOIntegration.md)
- [OpsgenieSdk::DeduplicationAction](docs/DeduplicationAction.md)
- [OpsgenieSdk::DelayAction](docs/DelayAction.md)
- [OpsgenieSdk::DeprecatedAlertPolicy](docs/DeprecatedAlertPolicy.md)
- [OpsgenieSdk::DeprecatedAlertPolicyMeta](docs/DeprecatedAlertPolicyMeta.md)
- [OpsgenieSdk::DeprecatedAutoCloseAlertPolicy](docs/DeprecatedAutoCloseAlertPolicy.md)
- [OpsgenieSdk::DeprecatedAutoRestartNotificationsAlertPolicy](docs/DeprecatedAutoRestartNotificationsAlertPolicy.md)
- [OpsgenieSdk::DeprecatedChangeAlertPolicyOrderPayload](docs/DeprecatedChangeAlertPolicyOrderPayload.md)
- [OpsgenieSdk::DeprecatedCreateAlertPolicyResponse](docs/DeprecatedCreateAlertPolicyResponse.md)
- [OpsgenieSdk::DeprecatedGetAlertPolicyResponse](docs/DeprecatedGetAlertPolicyResponse.md)
- [OpsgenieSdk::DeprecatedListAlertPoliciesResponse](docs/DeprecatedListAlertPoliciesResponse.md)
- [OpsgenieSdk::DeprecatedModifyAlertPolicy](docs/DeprecatedModifyAlertPolicy.md)
- [OpsgenieSdk::DeprecatedNotificationDeduplicationAlertPolicy](docs/DeprecatedNotificationDeduplicationAlertPolicy.md)
- [OpsgenieSdk::DeprecatedNotificationDelayAlertPolicy](docs/DeprecatedNotificationDelayAlertPolicy.md)
- [OpsgenieSdk::DeprecatedNotificationRenotifyAlertPolicy](docs/DeprecatedNotificationRenotifyAlertPolicy.md)
- [OpsgenieSdk::DeprecatedNotificationSuppressAlertPolicy](docs/DeprecatedNotificationSuppressAlertPolicy.md)
- [OpsgenieSdk::DeskCallback](docs/DeskCallback.md)
- [OpsgenieSdk::DeskIntegration](docs/DeskIntegration.md)
- [OpsgenieSdk::DetectifyIntegration](docs/DetectifyIntegration.md)
- [OpsgenieSdk::DisableHeartbeatResponse](docs/DisableHeartbeatResponse.md)
- [OpsgenieSdk::DisableIntegrationResponse](docs/DisableIntegrationResponse.md)
- [OpsgenieSdk::DnsCheckIntegration](docs/DnsCheckIntegration.md)
- [OpsgenieSdk::DripStatIntegration](docs/DripStatIntegration.md)
- [OpsgenieSdk::Duration](docs/Duration.md)
- [OpsgenieSdk::DynatraceAppMonCallback](docs/DynatraceAppMonCallback.md)
- [OpsgenieSdk::DynatraceAppMonIntegration](docs/DynatraceAppMonIntegration.md)
- [OpsgenieSdk::DynatraceIntegration](docs/DynatraceIntegration.md)
- [OpsgenieSdk::DynatraceV2Integration](docs/DynatraceV2Integration.md)
- [OpsgenieSdk::EmailBasedIncomingFeature](docs/EmailBasedIncomingFeature.md)
- [OpsgenieSdk::EmailIntegration](docs/EmailIntegration.md)
- [OpsgenieSdk::EnableHeartbeatResponse](docs/EnableHeartbeatResponse.md)
- [OpsgenieSdk::EnableIntegrationResponse](docs/EnableIntegrationResponse.md)
- [OpsgenieSdk::ErrorResponse](docs/ErrorResponse.md)
- [OpsgenieSdk::ErrorceptionIntegration](docs/ErrorceptionIntegration.md)
- [OpsgenieSdk::EscalateAlertToNextPayload](docs/EscalateAlertToNextPayload.md)
- [OpsgenieSdk::Escalation](docs/Escalation.md)
- [OpsgenieSdk::EscalationRecipient](docs/EscalationRecipient.md)
- [OpsgenieSdk::EscalationRepeat](docs/EscalationRepeat.md)
- [OpsgenieSdk::EscalationRule](docs/EscalationRule.md)
- [OpsgenieSdk::EvidentIOIntegration](docs/EvidentIOIntegration.md)
- [OpsgenieSdk::ExecuteCustomAlertActionPayload](docs/ExecuteCustomAlertActionPayload.md)
- [OpsgenieSdk::Filter](docs/Filter.md)
- [OpsgenieSdk::FlockCallback](docs/FlockCallback.md)
- [OpsgenieSdk::FlockIntegration](docs/FlockIntegration.md)
- [OpsgenieSdk::FlowdockCallback](docs/FlowdockCallback.md)
- [OpsgenieSdk::FlowdockIntegration](docs/FlowdockIntegration.md)
- [OpsgenieSdk::FlowdockV2Callback](docs/FlowdockV2Callback.md)
- [OpsgenieSdk::FlowdockV2Integration](docs/FlowdockV2Integration.md)
- [OpsgenieSdk::ForwardingRule](docs/ForwardingRule.md)
- [OpsgenieSdk::ForwardingRuleMeta](docs/ForwardingRuleMeta.md)
- [OpsgenieSdk::FreshdeskCallback](docs/FreshdeskCallback.md)
- [OpsgenieSdk::FreshdeskIntegration](docs/FreshdeskIntegration.md)
- [OpsgenieSdk::FreshserviceCallback](docs/FreshserviceCallback.md)
- [OpsgenieSdk::FreshserviceIntegration](docs/FreshserviceIntegration.md)
- [OpsgenieSdk::GetAccountInfoResponse](docs/GetAccountInfoResponse.md)
- [OpsgenieSdk::GetAlertAttachmentResponse](docs/GetAlertAttachmentResponse.md)
- [OpsgenieSdk::GetAlertResponse](docs/GetAlertResponse.md)
- [OpsgenieSdk::GetContactResponse](docs/GetContactResponse.md)
- [OpsgenieSdk::GetCountAlertsResponse](docs/GetCountAlertsResponse.md)
- [OpsgenieSdk::GetCountAlertsResponseData](docs/GetCountAlertsResponseData.md)
- [OpsgenieSdk::GetCustomUserRoleResponse](docs/GetCustomUserRoleResponse.md)
- [OpsgenieSdk::GetEscalationResponse](docs/GetEscalationResponse.md)
- [OpsgenieSdk::GetForwardingRuleResponse](docs/GetForwardingRuleResponse.md)
- [OpsgenieSdk::GetHeartbeatResponse](docs/GetHeartbeatResponse.md)
- [OpsgenieSdk::GetIncidentRequestStatusResponse](docs/GetIncidentRequestStatusResponse.md)
- [OpsgenieSdk::GetIncidentResponse](docs/GetIncidentResponse.md)
- [OpsgenieSdk::GetIntegrationResponse](docs/GetIntegrationResponse.md)
- [OpsgenieSdk::GetMaintenanceResponse](docs/GetMaintenanceResponse.md)
- [OpsgenieSdk::GetNextOnCallResponse](docs/GetNextOnCallResponse.md)
- [OpsgenieSdk::GetNotificationRuleResponse](docs/GetNotificationRuleResponse.md)
- [OpsgenieSdk::GetNotificationRuleStepResponse](docs/GetNotificationRuleStepResponse.md)
- [OpsgenieSdk::GetOnCallResponse](docs/GetOnCallResponse.md)
- [OpsgenieSdk::GetPolicyResponse](docs/GetPolicyResponse.md)
- [OpsgenieSdk::GetRequestStatusResponse](docs/GetRequestStatusResponse.md)
- [OpsgenieSdk::GetSavedSearchResponse](docs/GetSavedSearchResponse.md)
- [OpsgenieSdk::GetScheduleOverrideResponse](docs/GetScheduleOverrideResponse.md)
- [OpsgenieSdk::GetScheduleResponse](docs/GetScheduleResponse.md)
- [OpsgenieSdk::GetScheduleRotationResponse](docs/GetScheduleRotationResponse.md)
- [OpsgenieSdk::GetScheduleTimelineResponse](docs/GetScheduleTimelineResponse.md)
- [OpsgenieSdk::GetTeamResponse](docs/GetTeamResponse.md)
- [OpsgenieSdk::GetTeamRoleResponse](docs/GetTeamRoleResponse.md)
- [OpsgenieSdk::GetTeamRoutingRuleResponse](docs/GetTeamRoutingRuleResponse.md)
- [OpsgenieSdk::GetUserResponse](docs/GetUserResponse.md)
- [OpsgenieSdk::GhostInspectorIntegration](docs/GhostInspectorIntegration.md)
- [OpsgenieSdk::GitHubIntegration](docs/GitHubIntegration.md)
- [OpsgenieSdk::GitLabIntegration](docs/GitLabIntegration.md)
- [OpsgenieSdk::GoogleStackDriverIntegration](docs/GoogleStackDriverIntegration.md)
- [OpsgenieSdk::GrafanaIntegration](docs/GrafanaIntegration.md)
- [OpsgenieSdk::GrafanaV2Integration](docs/GrafanaV2Integration.md)
- [OpsgenieSdk::GraylogIntegration](docs/GraylogIntegration.md)
- [OpsgenieSdk::GroupRecipient](docs/GroupRecipient.md)
- [OpsgenieSdk::HPServiceManagerCallback](docs/HPServiceManagerCallback.md)
- [OpsgenieSdk::HPServiceManagerIntegration](docs/HPServiceManagerIntegration.md)
- [OpsgenieSdk::Heartbeat](docs/Heartbeat.md)
- [OpsgenieSdk::HeartbeatIntegration](docs/HeartbeatIntegration.md)
- [OpsgenieSdk::HeartbeatMeta](docs/HeartbeatMeta.md)
- [OpsgenieSdk::HipChatAddOnCallback](docs/HipChatAddOnCallback.md)
- [OpsgenieSdk::HipChatAddOnIntegration](docs/HipChatAddOnIntegration.md)
- [OpsgenieSdk::HipChatCallbackV2](docs/HipChatCallbackV2.md)
- [OpsgenieSdk::HipChatIntegration](docs/HipChatIntegration.md)
- [OpsgenieSdk::HipChatIntegrationV2](docs/HipChatIntegrationV2.md)
- [OpsgenieSdk::HoneybadgerIntegration](docs/HoneybadgerIntegration.md)
- [OpsgenieSdk::HostedGraphiteIntegration](docs/HostedGraphiteIntegration.md)
- [OpsgenieSdk::HumioIntegration](docs/HumioIntegration.md)
- [OpsgenieSdk::Icinga2Callback](docs/Icinga2Callback.md)
- [OpsgenieSdk::Icinga2Integration](docs/Icinga2Integration.md)
- [OpsgenieSdk::IcingaCallback](docs/IcingaCallback.md)
- [OpsgenieSdk::IcingaIntegration](docs/IcingaIntegration.md)
- [OpsgenieSdk::IgnoreIntegrationAction](docs/IgnoreIntegrationAction.md)
- [OpsgenieSdk::Incident](docs/Incident.md)
- [OpsgenieSdk::IncidentActionPayload](docs/IncidentActionPayload.md)
- [OpsgenieSdk::IncidentRequestStatus](docs/IncidentRequestStatus.md)
- [OpsgenieSdk::IncomingCallIntegration](docs/IncomingCallIntegration.md)
- [OpsgenieSdk::InstanaIntegration](docs/InstanaIntegration.md)
- [OpsgenieSdk::Integration](docs/Integration.md)
- [OpsgenieSdk::IntegrationActionFilter](docs/IntegrationActionFilter.md)
- [OpsgenieSdk::IntegrationCondition](docs/IntegrationCondition.md)
- [OpsgenieSdk::IntegrationMeta](docs/IntegrationMeta.md)
- [OpsgenieSdk::JenkinsIntegration](docs/JenkinsIntegration.md)
- [OpsgenieSdk::JiraCallback](docs/JiraCallback.md)
- [OpsgenieSdk::JiraIntegration](docs/JiraIntegration.md)
- [OpsgenieSdk::JiraServiceDeskCallback](docs/JiraServiceDeskCallback.md)
- [OpsgenieSdk::JiraServiceDeskIntegration](docs/JiraServiceDeskIntegration.md)
- [OpsgenieSdk::KapacitorIntegration](docs/KapacitorIntegration.md)
- [OpsgenieSdk::KayakoCallback](docs/KayakoCallback.md)
- [OpsgenieSdk::KayakoIntegration](docs/KayakoIntegration.md)
- [OpsgenieSdk::KoreCallback](docs/KoreCallback.md)
- [OpsgenieSdk::KoreIntegration](docs/KoreIntegration.md)
- [OpsgenieSdk::LabTechEmailIntegration](docs/LabTechEmailIntegration.md)
- [OpsgenieSdk::LibratoIntegration](docs/LibratoIntegration.md)
- [OpsgenieSdk::LibreNMSCallback](docs/LibreNMSCallback.md)
- [OpsgenieSdk::LibreNMSIntegration](docs/LibreNMSIntegration.md)
- [OpsgenieSdk::LightstepIntegration](docs/LightstepIntegration.md)
- [OpsgenieSdk::ListAlertAttachmentsResponse](docs/ListAlertAttachmentsResponse.md)
- [OpsgenieSdk::ListAlertLogsResponse](docs/ListAlertLogsResponse.md)
- [OpsgenieSdk::ListAlertNotesResponse](docs/ListAlertNotesResponse.md)
- [OpsgenieSdk::ListAlertRecipientsResponse](docs/ListAlertRecipientsResponse.md)
- [OpsgenieSdk::ListAlertsResponse](docs/ListAlertsResponse.md)
- [OpsgenieSdk::ListContactsResponse](docs/ListContactsResponse.md)
- [OpsgenieSdk::ListCustomUserRolesResponse](docs/ListCustomUserRolesResponse.md)
- [OpsgenieSdk::ListEscalationsResponse](docs/ListEscalationsResponse.md)
- [OpsgenieSdk::ListForwardingRulesResponse](docs/ListForwardingRulesResponse.md)
- [OpsgenieSdk::ListHeartbeatResponse](docs/ListHeartbeatResponse.md)
- [OpsgenieSdk::ListHeartbeatResponseData](docs/ListHeartbeatResponseData.md)
- [OpsgenieSdk::ListIncidentsResponse](docs/ListIncidentsResponse.md)
- [OpsgenieSdk::ListIntegrationActionsResponse](docs/ListIntegrationActionsResponse.md)
- [OpsgenieSdk::ListIntegrationsResponse](docs/ListIntegrationsResponse.md)
- [OpsgenieSdk::ListMaintenanceResponse](docs/ListMaintenanceResponse.md)
- [OpsgenieSdk::ListNotificationRuleStepsResponse](docs/ListNotificationRuleStepsResponse.md)
- [OpsgenieSdk::ListNotificationRulesResponse](docs/ListNotificationRulesResponse.md)
- [OpsgenieSdk::ListOnCallsResponse](docs/ListOnCallsResponse.md)
- [OpsgenieSdk::ListPoliciesResponse](docs/ListPoliciesResponse.md)
- [OpsgenieSdk::ListSavedSearchesResponse](docs/ListSavedSearchesResponse.md)
- [OpsgenieSdk::ListScheduleOverrideResponse](docs/ListScheduleOverrideResponse.md)
- [OpsgenieSdk::ListScheduleRotationsResponse](docs/ListScheduleRotationsResponse.md)
- [OpsgenieSdk::ListSchedulesResponse](docs/ListSchedulesResponse.md)
- [OpsgenieSdk::ListTeamLogsResponse](docs/ListTeamLogsResponse.md)
- [OpsgenieSdk::ListTeamRoleResponse](docs/ListTeamRoleResponse.md)
- [OpsgenieSdk::ListTeamRoutingRulesResponse](docs/ListTeamRoutingRulesResponse.md)
- [OpsgenieSdk::ListTeamsResponse](docs/ListTeamsResponse.md)
- [OpsgenieSdk::ListUserEscalationsResponse](docs/ListUserEscalationsResponse.md)
- [OpsgenieSdk::ListUserForwardingRulesResponse](docs/ListUserForwardingRulesResponse.md)
- [OpsgenieSdk::ListUserSchedulesResponse](docs/ListUserSchedulesResponse.md)
- [OpsgenieSdk::ListUserTeamsResponse](docs/ListUserTeamsResponse.md)
- [OpsgenieSdk::ListUsersResponse](docs/ListUsersResponse.md)
- [OpsgenieSdk::LogentriesIntegration](docs/LogentriesIntegration.md)
- [OpsgenieSdk::LogglyIntegration](docs/LogglyIntegration.md)
- [OpsgenieSdk::LogicMonitorCallback](docs/LogicMonitorCallback.md)
- [OpsgenieSdk::LogicMonitorIntegration](docs/LogicMonitorIntegration.md)
- [OpsgenieSdk::LogstashIntegration](docs/LogstashIntegration.md)
- [OpsgenieSdk::LogzIOIntegration](docs/LogzIOIntegration.md)
- [OpsgenieSdk::LookerIntegration](docs/LookerIntegration.md)
- [OpsgenieSdk::LoomIntegration](docs/LoomIntegration.md)
- [OpsgenieSdk::MSTeamsCallback](docs/MSTeamsCallback.md)
- [OpsgenieSdk::MSTeamsIntegration](docs/MSTeamsIntegration.md)
- [OpsgenieSdk::MSTeamsV2Callback](docs/MSTeamsV2Callback.md)
- [OpsgenieSdk::MSTeamsV2Integration](docs/MSTeamsV2Integration.md)
- [OpsgenieSdk::MagentrixCallback](docs/MagentrixCallback.md)
- [OpsgenieSdk::MagentrixIntegration](docs/MagentrixIntegration.md)
- [OpsgenieSdk::Maintenance](docs/Maintenance.md)
- [OpsgenieSdk::MaintenanceEntity](docs/MaintenanceEntity.md)
- [OpsgenieSdk::MaintenanceMeta](docs/MaintenanceMeta.md)
- [OpsgenieSdk::MaintenanceRule](docs/MaintenanceRule.md)
- [OpsgenieSdk::MaintenanceTime](docs/MaintenanceTime.md)
- [OpsgenieSdk::ManageEngineIntegrationDTO](docs/ManageEngineIntegrationDTO.md)
- [OpsgenieSdk::MaridCallback](docs/MaridCallback.md)
- [OpsgenieSdk::MaridIntegration](docs/MaridIntegration.md)
- [OpsgenieSdk::MatchAll](docs/MatchAll.md)
- [OpsgenieSdk::MatchAllConditions](docs/MatchAllConditions.md)
- [OpsgenieSdk::MatchAnyCondition](docs/MatchAnyCondition.md)
- [OpsgenieSdk::MattermostCallback](docs/MattermostCallback.md)
- [OpsgenieSdk::MattermostIntegration](docs/MattermostIntegration.md)
- [OpsgenieSdk::MongoDBCloudIntegration](docs/MongoDBCloudIntegration.md)
- [OpsgenieSdk::MonitisEmailIntegration](docs/MonitisEmailIntegration.md)
- [OpsgenieSdk::MonitisIntegration](docs/MonitisIntegration.md)
- [OpsgenieSdk::MoxtraCallback](docs/MoxtraCallback.md)
- [OpsgenieSdk::MoxtraIntegration](docs/MoxtraIntegration.md)
- [OpsgenieSdk::NagiosBasedV1Callback](docs/NagiosBasedV1Callback.md)
- [OpsgenieSdk::NagiosBasedV2Callback](docs/NagiosBasedV2Callback.md)
- [OpsgenieSdk::NagiosIntegrationV1](docs/NagiosIntegrationV1.md)
- [OpsgenieSdk::NagiosIntegrationV2](docs/NagiosIntegrationV2.md)
- [OpsgenieSdk::NagiosXIIntegrationV1](docs/NagiosXIIntegrationV1.md)
- [OpsgenieSdk::NagiosXIIntegrationV2](docs/NagiosXIIntegrationV2.md)
- [OpsgenieSdk::NagiosXIV1Callback](docs/NagiosXIV1Callback.md)
- [OpsgenieSdk::NagiosXIV2Callback](docs/NagiosXIV2Callback.md)
- [OpsgenieSdk::NetuitiveIntegration](docs/NetuitiveIntegration.md)
- [OpsgenieSdk::NeustarIntegration](docs/NeustarIntegration.md)
- [OpsgenieSdk::NewRelicIntegration](docs/NewRelicIntegration.md)
- [OpsgenieSdk::NewRelicV2Integration](docs/NewRelicV2Integration.md)
- [OpsgenieSdk::NextOnCall](docs/NextOnCall.md)
- [OpsgenieSdk::NoRecipient](docs/NoRecipient.md)
- [OpsgenieSdk::NodePingIntegration](docs/NodePingIntegration.md)
- [OpsgenieSdk::NotificationActionType](docs/NotificationActionType.md)
- [OpsgenieSdk::NotificationPolicy](docs/NotificationPolicy.md)
- [OpsgenieSdk::NotificationRepeat](docs/NotificationRepeat.md)
- [OpsgenieSdk::NotificationRule](docs/NotificationRule.md)
- [OpsgenieSdk::NotificationRuleMeta](docs/NotificationRuleMeta.md)
- [OpsgenieSdk::NotificationRuleStep](docs/NotificationRuleStep.md)
- [OpsgenieSdk::NotificationRuleStepParent](docs/NotificationRuleStepParent.md)
- [OpsgenieSdk::NotifyTime](docs/NotifyTime.md)
- [OpsgenieSdk::OECCallback](docs/OECCallback.md)
- [OpsgenieSdk::OECIntegration](docs/OECIntegration.md)
- [OpsgenieSdk::OEMEmailIntegration](docs/OEMEmailIntegration.md)
- [OpsgenieSdk::OEMIntegration](docs/OEMIntegration.md)
- [OpsgenieSdk::OP5Callback](docs/OP5Callback.md)
- [OpsgenieSdk::OP5Integration](docs/OP5Integration.md)
- [OpsgenieSdk::ObserviumIntegration](docs/ObserviumIntegration.md)
- [OpsgenieSdk::ObserviumV2Integration](docs/ObserviumV2Integration.md)
- [OpsgenieSdk::OnCall](docs/OnCall.md)
- [OpsgenieSdk::OpsDashIntegration](docs/OpsDashIntegration.md)
- [OpsgenieSdk::OpsGenieCallback](docs/OpsGenieCallback.md)
- [OpsgenieSdk::OpsGenieIntegration](docs/OpsGenieIntegration.md)
- [OpsgenieSdk::OpsviewIntegration](docs/OpsviewIntegration.md)
- [OpsgenieSdk::OutgoingCallback](docs/OutgoingCallback.md)
- [OpsgenieSdk::OutgoingCallbackNew](docs/OutgoingCallbackNew.md)
- [OpsgenieSdk::PageDetails](docs/PageDetails.md)
- [OpsgenieSdk::PagerDutyCompatibilityIntegration](docs/PagerDutyCompatibilityIntegration.md)
- [OpsgenieSdk::PanoptaIntegration](docs/PanoptaIntegration.md)
- [OpsgenieSdk::PapertrailIntegration](docs/PapertrailIntegration.md)
- [OpsgenieSdk::Participant](docs/Participant.md)
- [OpsgenieSdk::PingdomIntegration](docs/PingdomIntegration.md)
- [OpsgenieSdk::PingdomV2Integration](docs/PingdomV2Integration.md)
- [OpsgenieSdk::PingdomWebhookIntegration](docs/PingdomWebhookIntegration.md)
- [OpsgenieSdk::PingometerIntegration](docs/PingometerIntegration.md)
- [OpsgenieSdk::PlanioCallback](docs/PlanioCallback.md)
- [OpsgenieSdk::PlanioIntegration](docs/PlanioIntegration.md)
- [OpsgenieSdk::Policy](docs/Policy.md)
- [OpsgenieSdk::PolicyMeta](docs/PolicyMeta.md)
- [OpsgenieSdk::PrometheusIntegration](docs/PrometheusIntegration.md)
- [OpsgenieSdk::PrtgCallback](docs/PrtgCallback.md)
- [OpsgenieSdk::PrtgIntegration](docs/PrtgIntegration.md)
- [OpsgenieSdk::RackspaceIntegration](docs/RackspaceIntegration.md)
- [OpsgenieSdk::RaygunIntegration](docs/RaygunIntegration.md)
- [OpsgenieSdk::Recipient](docs/Recipient.md)
- [OpsgenieSdk::RedGateSqlMonitorEmailIntegration](docs/RedGateSqlMonitorEmailIntegration.md)
- [OpsgenieSdk::Responder](docs/Responder.md)
- [OpsgenieSdk::RiemannIntegration](docs/RiemannIntegration.md)
- [OpsgenieSdk::RigorIntegration](docs/RigorIntegration.md)
- [OpsgenieSdk::RingCentralEmailIntegration](docs/RingCentralEmailIntegration.md)
- [OpsgenieSdk::RingCentralGlipCallback](docs/RingCentralGlipCallback.md)
- [OpsgenieSdk::RingCentralGlipIntegration](docs/RingCentralGlipIntegration.md)
- [OpsgenieSdk::RollbarCallback](docs/RollbarCallback.md)
- [OpsgenieSdk::RollbarIntegration](docs/RollbarIntegration.md)
- [OpsgenieSdk::RunscopeIntegration](docs/RunscopeIntegration.md)
- [OpsgenieSdk::SalesForceServiceCloudCallback](docs/SalesForceServiceCloudCallback.md)
- [OpsgenieSdk::SalesForceServiceCloudIntegration](docs/SalesForceServiceCloudIntegration.md)
- [OpsgenieSdk::SaltStackIntegration](docs/SaltStackIntegration.md)
- [OpsgenieSdk::SavedSearch](docs/SavedSearch.md)
- [OpsgenieSdk::SavedSearchEntity](docs/SavedSearchEntity.md)
- [OpsgenieSdk::SavedSearchMeta](docs/SavedSearchMeta.md)
- [OpsgenieSdk::ScalyrIntegration](docs/ScalyrIntegration.md)
- [OpsgenieSdk::Schedule](docs/Schedule.md)
- [OpsgenieSdk::ScheduleMeta](docs/ScheduleMeta.md)
- [OpsgenieSdk::ScheduleOverride](docs/ScheduleOverride.md)
- [OpsgenieSdk::ScheduleOverrideMeta](docs/ScheduleOverrideMeta.md)
- [OpsgenieSdk::ScheduleOverrideRotation](docs/ScheduleOverrideRotation.md)
- [OpsgenieSdk::ScheduleRecipient](docs/ScheduleRecipient.md)
- [OpsgenieSdk::ScheduleRotation](docs/ScheduleRotation.md)
- [OpsgenieSdk::ScheduleRotationWithParent](docs/ScheduleRotationWithParent.md)
- [OpsgenieSdk::ScheduleTimeline](docs/ScheduleTimeline.md)
- [OpsgenieSdk::ScomIntegration](docs/ScomIntegration.md)
- [OpsgenieSdk::ScoutIntegration](docs/ScoutIntegration.md)
- [OpsgenieSdk::SematextSpmIntegration](docs/SematextSpmIntegration.md)
- [OpsgenieSdk::SensuIntegration](docs/SensuIntegration.md)
- [OpsgenieSdk::SentryIntegration](docs/SentryIntegration.md)
- [OpsgenieSdk::ServerDensityIntegration](docs/ServerDensityIntegration.md)
- [OpsgenieSdk::ServerGuard24Integration](docs/ServerGuard24Integration.md)
- [OpsgenieSdk::ServiceNowIntegration](docs/ServiceNowIntegration.md)
- [OpsgenieSdk::ServiceNowV2Callback](docs/ServiceNowV2Callback.md)
- [OpsgenieSdk::ServiceNowV2Integration](docs/ServiceNowV2Integration.md)
- [OpsgenieSdk::ServiceNowV3Callback](docs/ServiceNowV3Callback.md)
- [OpsgenieSdk::ServiceNowV3Integration](docs/ServiceNowV3Integration.md)
- [OpsgenieSdk::SignalFXV2Integration](docs/SignalFXV2Integration.md)
- [OpsgenieSdk::SignalSciencesIntegration](docs/SignalSciencesIntegration.md)
- [OpsgenieSdk::SignalfxIntegration](docs/SignalfxIntegration.md)
- [OpsgenieSdk::Site24x7Integration](docs/Site24x7Integration.md)
- [OpsgenieSdk::SlackAppCallback](docs/SlackAppCallback.md)
- [OpsgenieSdk::SlackAppIntegration](docs/SlackAppIntegration.md)
- [OpsgenieSdk::SlackCallback](docs/SlackCallback.md)
- [OpsgenieSdk::SlackIntegration](docs/SlackIntegration.md)
- [OpsgenieSdk::SnoozeAlertPayload](docs/SnoozeAlertPayload.md)
- [OpsgenieSdk::SoastaIntegration](docs/SoastaIntegration.md)
- [OpsgenieSdk::SolarWindsWebHelpDeskCallback](docs/SolarWindsWebHelpDeskCallback.md)
- [OpsgenieSdk::SolarWindsWebHelpDeskIntegration](docs/SolarWindsWebHelpDeskIntegration.md)
- [OpsgenieSdk::SolarwindsCallback](docs/SolarwindsCallback.md)
- [OpsgenieSdk::SolarwindsIntegration](docs/SolarwindsIntegration.md)
- [OpsgenieSdk::SolarwindsMSPNCentralIntegration](docs/SolarwindsMSPNCentralIntegration.md)
- [OpsgenieSdk::SolarwindsMSPNcentralCallback](docs/SolarwindsMSPNcentralCallback.md)
- [OpsgenieSdk::SplunkCallback](docs/SplunkCallback.md)
- [OpsgenieSdk::SplunkITSICallback](docs/SplunkITSICallback.md)
- [OpsgenieSdk::SplunkITSIIntegration](docs/SplunkITSIIntegration.md)
- [OpsgenieSdk::SplunkIntegration](docs/SplunkIntegration.md)
- [OpsgenieSdk::StackStormIntegration](docs/StackStormIntegration.md)
- [OpsgenieSdk::StackdriverCallback](docs/StackdriverCallback.md)
- [OpsgenieSdk::StackdriverIntegration](docs/StackdriverIntegration.md)
- [OpsgenieSdk::StatusCakeIntegration](docs/StatusCakeIntegration.md)
- [OpsgenieSdk::StatusHubIntegration](docs/StatusHubIntegration.md)
- [OpsgenieSdk::StatusIOCallback](docs/StatusIOCallback.md)
- [OpsgenieSdk::StatusIOIntegration](docs/StatusIOIntegration.md)
- [OpsgenieSdk::StatusPageEntry](docs/StatusPageEntry.md)
- [OpsgenieSdk::StatusPageIOCallback](docs/StatusPageIOCallback.md)
- [OpsgenieSdk::StatusPageIOIntegration](docs/StatusPageIOIntegration.md)
- [OpsgenieSdk::StatusyCallback](docs/StatusyCallback.md)
- [OpsgenieSdk::StatusyIntegration](docs/StatusyIntegration.md)
- [OpsgenieSdk::StruxureWareIntegration](docs/StruxureWareIntegration.md)
- [OpsgenieSdk::SuccessData](docs/SuccessData.md)
- [OpsgenieSdk::SuccessResponse](docs/SuccessResponse.md)
- [OpsgenieSdk::SumoLogicCallback](docs/SumoLogicCallback.md)
- [OpsgenieSdk::SumoLogicIntegration](docs/SumoLogicIntegration.md)
- [OpsgenieSdk::SysdigCloudIntegration](docs/SysdigCloudIntegration.md)
- [OpsgenieSdk::Team](docs/Team.md)
- [OpsgenieSdk::TeamLog](docs/TeamLog.md)
- [OpsgenieSdk::TeamLogDetails](docs/TeamLogDetails.md)
- [OpsgenieSdk::TeamMember](docs/TeamMember.md)
- [OpsgenieSdk::TeamMeta](docs/TeamMeta.md)
- [OpsgenieSdk::TeamRecipient](docs/TeamRecipient.md)
- [OpsgenieSdk::TeamResponder](docs/TeamResponder.md)
- [OpsgenieSdk::TeamRight](docs/TeamRight.md)
- [OpsgenieSdk::TeamRole](docs/TeamRole.md)
- [OpsgenieSdk::TeamRoutingRule](docs/TeamRoutingRule.md)
- [OpsgenieSdk::ThousandEyesIntegration](docs/ThousandEyesIntegration.md)
- [OpsgenieSdk::ThreatStackIntegration](docs/ThreatStackIntegration.md)
- [OpsgenieSdk::ThundraIntegration](docs/ThundraIntegration.md)
- [OpsgenieSdk::TidewaysIntegration](docs/TidewaysIntegration.md)
- [OpsgenieSdk::TimeOfDayRestriction](docs/TimeOfDayRestriction.md)
- [OpsgenieSdk::TimeOfDayRestrictionInterval](docs/TimeOfDayRestrictionInterval.md)
- [OpsgenieSdk::TimeRestrictionInterval](docs/TimeRestrictionInterval.md)
- [OpsgenieSdk::Timeline](docs/Timeline.md)
- [OpsgenieSdk::TimelinePeriod](docs/TimelinePeriod.md)
- [OpsgenieSdk::TimelineRecipient](docs/TimelineRecipient.md)
- [OpsgenieSdk::TimelineRotation](docs/TimelineRotation.md)
- [OpsgenieSdk::TokenBasedIncomingFeature](docs/TokenBasedIncomingFeature.md)
- [OpsgenieSdk::TraceIntegration](docs/TraceIntegration.md)
- [OpsgenieSdk::TrackItCallback](docs/TrackItCallback.md)
- [OpsgenieSdk::TrackItIntegration](docs/TrackItIntegration.md)
- [OpsgenieSdk::TravisCIIntegration](docs/TravisCIIntegration.md)
- [OpsgenieSdk::TwilioIntegration](docs/TwilioIntegration.md)
- [OpsgenieSdk::UnAcknowledgeAlertPayload](docs/UnAcknowledgeAlertPayload.md)
- [OpsgenieSdk::UpdateAlertDescriptionPayload](docs/UpdateAlertDescriptionPayload.md)
- [OpsgenieSdk::UpdateAlertMessagePayload](docs/UpdateAlertMessagePayload.md)
- [OpsgenieSdk::UpdateAlertPriorityPayload](docs/UpdateAlertPriorityPayload.md)
- [OpsgenieSdk::UpdateContactPayload](docs/UpdateContactPayload.md)
- [OpsgenieSdk::UpdateCustomUserRolePayload](docs/UpdateCustomUserRolePayload.md)
- [OpsgenieSdk::UpdateEscalationPayload](docs/UpdateEscalationPayload.md)
- [OpsgenieSdk::UpdateForwardingRulePayload](docs/UpdateForwardingRulePayload.md)
- [OpsgenieSdk::UpdateHeartbeatPayload](docs/UpdateHeartbeatPayload.md)
- [OpsgenieSdk::UpdateHeartbeatResponse](docs/UpdateHeartbeatResponse.md)
- [OpsgenieSdk::UpdateIntegrationActionsResponse](docs/UpdateIntegrationActionsResponse.md)
- [OpsgenieSdk::UpdateIntegrationResponse](docs/UpdateIntegrationResponse.md)
- [OpsgenieSdk::UpdateMaintenancePayload](docs/UpdateMaintenancePayload.md)
- [OpsgenieSdk::UpdateMaintenanceResponse](docs/UpdateMaintenanceResponse.md)
- [OpsgenieSdk::UpdateNotificationRulePayload](docs/UpdateNotificationRulePayload.md)
- [OpsgenieSdk::UpdateNotificationRuleResponse](docs/UpdateNotificationRuleResponse.md)
- [OpsgenieSdk::UpdateNotificationRuleStepPayload](docs/UpdateNotificationRuleStepPayload.md)
- [OpsgenieSdk::UpdateSavedSearchPayload](docs/UpdateSavedSearchPayload.md)
- [OpsgenieSdk::UpdateScheduleOverridePayload](docs/UpdateScheduleOverridePayload.md)
- [OpsgenieSdk::UpdateScheduleOverrideResponse](docs/UpdateScheduleOverrideResponse.md)
- [OpsgenieSdk::UpdateSchedulePayload](docs/UpdateSchedulePayload.md)
- [OpsgenieSdk::UpdateScheduleResponse](docs/UpdateScheduleResponse.md)
- [OpsgenieSdk::UpdateScheduleRotationPayload](docs/UpdateScheduleRotationPayload.md)
- [OpsgenieSdk::UpdateTeamPayload](docs/UpdateTeamPayload.md)
- [OpsgenieSdk::UpdateTeamRolePayload](docs/UpdateTeamRolePayload.md)
- [OpsgenieSdk::UpdateTeamRoutingRulePayload](docs/UpdateTeamRoutingRulePayload.md)
- [OpsgenieSdk::UpdateUserPayload](docs/UpdateUserPayload.md)
- [OpsgenieSdk::UpdownIOIntegration](docs/UpdownIOIntegration.md)
- [OpsgenieSdk::UptimeRobotEmailIntegration](docs/UptimeRobotEmailIntegration.md)
- [OpsgenieSdk::UptimeRobotIntegration](docs/UptimeRobotIntegration.md)
- [OpsgenieSdk::UptimeWebhookIntegration](docs/UptimeWebhookIntegration.md)
- [OpsgenieSdk::UptrendsEmailIntegration](docs/UptrendsEmailIntegration.md)
- [OpsgenieSdk::User](docs/User.md)
- [OpsgenieSdk::UserAddress](docs/UserAddress.md)
- [OpsgenieSdk::UserContact](docs/UserContact.md)
- [OpsgenieSdk::UserMeta](docs/UserMeta.md)
- [OpsgenieSdk::UserRecipient](docs/UserRecipient.md)
- [OpsgenieSdk::UserResponder](docs/UserResponder.md)
- [OpsgenieSdk::UserRole](docs/UserRole.md)
- [OpsgenieSdk::VCSAIntegration](docs/VCSAIntegration.md)
- [OpsgenieSdk::VCenterIntegration](docs/VCenterIntegration.md)
- [OpsgenieSdk::VividCortexIntegration](docs/VividCortexIntegration.md)
- [OpsgenieSdk::WavefrontIntegration](docs/WavefrontIntegration.md)
- [OpsgenieSdk::WebhookCallback](docs/WebhookCallback.md)
- [OpsgenieSdk::WebhookIntegration](docs/WebhookIntegration.md)
- [OpsgenieSdk::WeekdayTimeRestriction](docs/WeekdayTimeRestriction.md)
- [OpsgenieSdk::WeekdayTimeRestrictionInterval](docs/WeekdayTimeRestrictionInterval.md)
- [OpsgenieSdk::WhatsUpGoldIntegration](docs/WhatsUpGoldIntegration.md)
- [OpsgenieSdk::WorkatoIntegration](docs/WorkatoIntegration.md)
- [OpsgenieSdk::XLReleaseIntegration](docs/XLReleaseIntegration.md)
- [OpsgenieSdk::XPackAlertingCallback](docs/XPackAlertingCallback.md)
- [OpsgenieSdk::XPackAlertingIntegration](docs/XPackAlertingIntegration.md)
- [OpsgenieSdk::XmppCallback](docs/XmppCallback.md)
- [OpsgenieSdk::XmppIntegration](docs/XmppIntegration.md)
- [OpsgenieSdk::ZabbixCallback](docs/ZabbixCallback.md)
- [OpsgenieSdk::ZabbixIntegration](docs/ZabbixIntegration.md)
- [OpsgenieSdk::ZapierIntegration](docs/ZapierIntegration.md)
- [OpsgenieSdk::ZendeskCallback](docs/ZendeskCallback.md)
- [OpsgenieSdk::ZendeskIntegration](docs/ZendeskIntegration.md)
- [OpsgenieSdk::ZenossCallback](docs/ZenossCallback.md)
- [OpsgenieSdk::ZenossIntegration](docs/ZenossIntegration.md)
- [OpsgenieSdk::ZyrionIntegration](docs/ZyrionIntegration.md)

## Documentation for Authorization

### GenieKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header
